;-----> Detect a file (modified version of IonDetect)
;       By Paul Marks
; input:
;       hl=place to start looking
;       ix->first line of data (0 terminated)
;       (detectSMC_tempMem) = place to save unarchived data.
; output:
;       de=place stopped + 1
;       hl->program data (after the string)
;       (detectSMC_tempMem) = byte after end of data
;       z=0 if found, z=1 if not found.
;       All registers destroyed

#ifdef MIRAGE
myDetect:
        ld      de,(ptemp)
        bcall(_cphlde)
        ld      a,(hl)
        jr      nz,detectContinue
        inc     a
        ret
detectContinue:
        push    hl
        and     $01
        jr      nz,detectSkip

        dec     hl
        dec     hl
        dec     hl      ; hl->lsb ptr
        ld      e,(hl)
        dec     hl
        ld      d,(hl)
        dec     hl      ; hl->page
        ld      a,(hl)
        or      a
        push    af
        ld      h,d
        ld      l,e     ; hl & de->program
        jr      z,detectNoMove

        push    hl
        ld      hl,(detectSMC_tempMem)
        ld      de,(tempMem)
        sbc     hl,de
        ld      de,MEM_NEEDED+64
        add     hl,de
        bcall(_EnoughMem)
        pop     hl

        jr      c,detectNotEnough
        ld      de,$0000
detectSMC_tempMem = $-2
        push    ix
        push    hl
        push    de
        ld      bc,64
        bcall(_FlashToRam)
        pop     hl
        push    hl
        pop     ix
        ld      a,10
        add     a,(ix+9)
        ld      e,a
        ld      d,0     ; de=flash offset
        add     hl,de
        ex      (sp),hl
        add     hl,de
        pop     de
        ex      de,hl   ; hl-temp, de-perm
        pop     ix
detectNoMove:
        inc     de
        inc     de
        ld      c,(hl)
        inc     hl
        ld      b,(hl)
        inc     hl      ; hl->data in ram
        push    bc
        push    ix
        pop     bc
detectCheck:
        ld      a,(bc)
        or      a
        jr      z,detectFound
        cp      (hl)
        inc     bc
        inc     de
        inc     hl
        jr      z,detectCheck
detectBad:
        pop     bc
detectNotEnough:
        pop     af
detectSkip:
        pop     hl
        ld      bc,-6
        add     hl,bc
        ld      b,(hl)
        dec     hl
detectNameLoop2:
        dec     hl
        djnz    detectNameLoop2
        jr      myDetect
detectFound:
        pop     hl
        ; hl=size, de->data
        pop     af      ; a=page, f=(or a)
        jr      z,detectInRam
        push    de      ; data
        push    af
        push    hl

        push    hl
        ld      bc,(detectSMC_tempMem)
        add     hl,bc
        ld      bc,(tempMem)
        sbc     hl,bc
        ld      bc,MEM_NEEDED
        add     hl,bc
        bcall(_EnoughMem)
        pop     hl
        
        pop     bc
        jr      c,detectBad
        pop     af

        ld      de,(detectSMC_tempMem)
        ld      h,d
        ld      l,e
        add     hl,bc
        ld      (detectSMC_tempMem),hl
        
        pop     hl
        push    de
        bcall(_FlashToRam)
        pop     de
detectInRam:    ; de->data in RAM
        pop     hl      ; hl->vat location
        ld      bc,-6
        add     hl,bc
        ld      b,(hl)
        inc     b
detectNameLoop1:
        dec     hl
        djnz    detectNameLoop1
        ex      de,hl
        xor     a
        ret
#endif
.end
